@@ -1,15 +1,13 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '0.120090'; # VERSION
+our $VERSION = '1.120030'; # VERSION
 
 # Dependencies
 use autodie 2.00;
 use Moose 0.99;
 use Moose::Autobox;
 use namespace::autoclean 0.09;
-use CPAN::Meta;
-use Try::Tiny;
 
 use Dist::Zilla 4.3; # authordeps
 
@@ -33,17 +31,14 @@ use Dist::Zilla::Plugin::Test::PodSpelling 2.001002 ();
 use Dist::Zilla::Plugin::Test::Perl::Critic ();
 use Dist::Zilla::Plugin::PodWeaver ();
 use Dist::Zilla::Plugin::Test::Portability ();
-use Dist::Zilla::Plugin::ReadmeAnyFromPod 0.120051 ();
+use Dist::Zilla::Plugin::ReadmeAnyFromPod ();
 use Dist::Zilla::Plugin::ReadmeFromPod ();
 use Dist::Zilla::Plugin::TaskWeaver 0.101620 ();
 use Dist::Zilla::Plugin::Test::Version ();
 
-use Dist::Zilla::PluginBundle::MITHALDU::Templates;
-use Dist::Zilla::Util::FileGenerator;
-
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-sub mvp_multivalue_args { qw/stopwords gitignore exclude_match/ }
+sub mvp_multivalue_args { qw/stopwords/ }
 
 has stopwords => (
   is      => 'ro',
@@ -114,50 +109,6 @@ has git_remote => (
   },
 );
 
-has major_version => (
-  is      => 'ro',
-  isa     => 'Int',
-  lazy    => 1,
-  default => sub {
-    exists $_[0]->payload->{major_version} ? $_[0]->payload->{major_version} : 1
-  },
-);
-
-has gitignore => (
-  is      => 'ro',
-  isa     => 'ArrayRef',
-  lazy    => 1,
-  default => sub {
-    exists $_[0]->payload->{gitignore} ? $_[0]->payload->{gitignore} : []
-  },
-);
-
-has exclude_match => (
-  is      => 'ro',
-  isa     => 'ArrayRef',
-  lazy    => 1,
-  default => sub {
-    exists $_[0]->payload->{exclude_match} ? $_[0]->payload->{exclude_match} : []
-  },
-);
-
-sub old_meta {
-  my $meta = try {
-    CPAN::Meta->load_file("META.json");
-  }
-  catch {
-    warn "META.json could not be read, using fallback meta. Error:\n $_";
-    return { version => 0.1, resources => { homepage => 'http://homepage', repository => { web => "user/repo" } } };
-  };
-
-  my @github_url = split '/', $meta->{resources}{repository}{web};
-  my ( $old_repo, $old_user ) = ( pop @github_url, pop @github_url );
-  my $github = [ homepage => $meta->{resources}{homepage}, repo => $old_repo, user => $old_user ];
-
-  my $version = $meta->{version};
-
-  return ( $version, $github, $meta );
-}
 
 sub configure {
   my $self = shift;
@@ -165,31 +116,13 @@ sub configure {
   my @push_to = ('origin');
   push @push_to, $self->git_remote if $self->git_remote ne 'origin';
 
-  my $gitignore_extra = join "\n", $self->gitignore->flatten;
-
-  my $gen = Dist::Zilla::Util::FileGenerator->new(
-    files => [
-      [ '.gitignore' => ( extra_content => $gitignore_extra, move => 1 ) ],
-      'README.PATCHING',
-      'perlcritic.rc',
-    ],
-    source => "Dist::Zilla::PluginBundle::MITHALDU::Templates",
-  );
-
-  my ( $old_version, $old_github ) = $self->old_meta;
-
-  my $version_provider = ['StaticVersion' => { version => $old_version } ];
-
-  my $is_release = grep /^release$/, @ARGV;
-  $version_provider = [ 'AutoVersion' => { major => $self->major_version } ] if $is_release;
-
-  my @plugins = (
+  $self->add_plugins (
 
   # version number
-    $version_provider,
+    [ 'AutoVersion' ],
 
   # gather and prune
-    [ GatherDir => { exclude_filename => [qw/README.pod META.json/], exclude_match => $self->exclude_match }], # core
+    [ GatherDir => { exclude_filename => [qw/README.pod META.json/] }], # core
     'PruneCruft',         # core
     'ManifestSkip',       # core
 
@@ -226,7 +159,7 @@ sub configure {
   # metadata
     'MinimumPerl',
     ( $self->auto_prereq ? 'AutoPrereqs' : () ),
-    [ GithubMeta => { remote => $self->git_remote, ( $is_release ? () : @{$old_github} ) } ],
+    [ GithubMeta => { remote => $self->git_remote } ],
     [ MetaNoIndex => {
         directory => [qw/t xt examples corpus/],
         'package' => [qw/DB/]
@@ -281,10 +214,6 @@ sub configure {
 
   );
 
-  @plugins = $gen->combine_with( @plugins );
-
-  $self->add_plugins( @plugins );
-
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -299,7 +228,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This is free software, licensed under:
 #
-#   DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, Version 2, December 2004
+#   The Apache License, Version 2.0, January 2004
 #
 
 
@@ -312,7 +241,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 0.120090
+version 1.120030
 
 =head1 SYNOPSIS
 
@@ -329,20 +258,13 @@ following dist.ini:
 
    ; version provider
    [AutoVersion]  ; build a version from the date
-   major = 1
  
    ; choose files to include
    [GatherDir]         ; everything under top dir
    exclude_filename = README.pod   ; skip this generated file
    exclude_filename = META.json    ; skip this generated file
-   exclude_filename = .gitignore   ; skip this generated file
-   exclude_filename = README.PATCHING ; skip this generated file
-   exclude_filename = perlcritic.rc   ; skip this generated file
  
    [PruneCruft]        ; default stuff to skip
-   except = .gitignore
-   except = README.PATCHING
-   except = perlcritic.rc
    [ManifestSkip]      ; if -f MANIFEST.SKIP, skip those, too
  
    ; file modifications
@@ -358,22 +280,6 @@ following dist.ini:
    type = pod
    filename = README.pod
    location = root
-   [GenerateFile]
-   filename    = .gitignore
-   is_template = 1
-   content = /.build
-   content = /{{ $dist->name }}-*
-   ; and more, see Dist::Zilla::PluginBundle::MITHALDU::Templates
-   [GenerateFile]
-   filename    = README.PATCHING
-   is_template = 1
-   content = README.PATCHING
-   ; and more, see Dist::Zilla::PluginBundle::MITHALDU::Templates
-   [GenerateFile]
-   filename    = perlcritic.rc
-   is_template = 1
-   content = README.PATCHING
-   ; and more, see Dist::Zilla::PluginBundle::MITHALDU::Templates
  
    ; t tests
    [Test::Compile]     ; make sure .pm files all compile
@@ -419,9 +325,6 @@ following dist.ini:
    ; copy META.json back to repo dis
    [CopyFilesFromBuild]
    copy = META.json
-   move = .gitignore
-   copy = README.PATCHING
-   copy = perlcritic.rc
  
    ; before release
    [Git::Check]        ; ensure all files checked in
@@ -457,7 +360,7 @@ following dist.ini:
 =for stopwords autoprereq mithaldu fakerelease pluginbundle podweaver
 taskweaver uploadtocpan dist ini
 
-=for Pod::Coverage configure mvp_multivalue_args old_meta
+=for Pod::Coverage configure mvp_multivalue_args
 
 =head1 USAGE
 
@@ -483,10 +386,6 @@ robust than just the version number when parsing versions
 
 =item *
 
-C<<< major_version >>> -- overrides the major version set by AutoVersion
-
-=item *
-
 C<<< fake_release >>> -- swaps FakeRelease for UploadToCPAN. Mostly useful for
 testing a dist.ini without risking a real release.
 
@@ -506,14 +405,6 @@ C<<< no_critic >>> -- omit Test::Perl::Critic tests
 
 C<<< no_spellcheck >>> -- omit Test::PodSpelling tests
 
-=item *
-
-C<<< gitignore >>> -- adds entries to be added to .gitignore (can be repeated)
-
-=item *
-
-C<<< exclude_match >>> -- regexes to exclude files from the dist (can be repeated)
-
 =back
 
 =head1 SEE ALSO
@@ -573,7 +464,7 @@ This software is Copyright (c) 2012 by Christian Walde.
 
 This is free software, licensed under:
 
-  DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, Version 2, December 2004
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
